# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rtde.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import rtde_msgs_pb2 as rtde__msgs__pb2
import common_msgs_pb2 as common__msgs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rtde.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\nrtde.proto\x12\x12Nrmk.IndyFramework\x1a\x0frtde_msgs.proto\x1a\x11\x63ommon_msgs.proto2\x8b\x05\n\x0eRTDataExchange\x12L\n\rGetMotionData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1e.Nrmk.IndyFramework.MotionData\"\x00\x12N\n\x0eGetControlData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.ControlData\"\x00\x12P\n\x0fGetControlState\x12\x19.Nrmk.IndyFramework.Empty\x1a .Nrmk.IndyFramework.ControlData2\"\x00\x12\x44\n\tGetIOData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1a.Nrmk.IndyFramework.IOData\"\x00\x12J\n\x0cGetServoData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1d.Nrmk.IndyFramework.ServoData\"\x00\x12R\n\x10GetViolationData\x12\x19.Nrmk.IndyFramework.Empty\x1a!.Nrmk.IndyFramework.ViolationData\"\x00\x12N\n\x0eGetProgramData\x12\x19.Nrmk.IndyFramework.Empty\x1a\x1f.Nrmk.IndyFramework.ProgramData\"\x00\x12S\n\x0cTestFunction\x12\x1f.Nrmk.IndyFramework.TestRequest\x1a .Nrmk.IndyFramework.TestResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[rtde__msgs__pb2.DESCRIPTOR,common__msgs__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_RTDATAEXCHANGE = _descriptor.ServiceDescriptor(
  name='RTDataExchange',
  full_name='Nrmk.IndyFramework.RTDataExchange',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=71,
  serialized_end=722,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMotionData',
    full_name='Nrmk.IndyFramework.RTDataExchange.GetMotionData',
    index=0,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=rtde__msgs__pb2._MOTIONDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetControlData',
    full_name='Nrmk.IndyFramework.RTDataExchange.GetControlData',
    index=1,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=rtde__msgs__pb2._CONTROLDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetControlState',
    full_name='Nrmk.IndyFramework.RTDataExchange.GetControlState',
    index=2,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=rtde__msgs__pb2._CONTROLDATA2,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIOData',
    full_name='Nrmk.IndyFramework.RTDataExchange.GetIOData',
    index=3,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=rtde__msgs__pb2._IODATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServoData',
    full_name='Nrmk.IndyFramework.RTDataExchange.GetServoData',
    index=4,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=rtde__msgs__pb2._SERVODATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetViolationData',
    full_name='Nrmk.IndyFramework.RTDataExchange.GetViolationData',
    index=5,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=rtde__msgs__pb2._VIOLATIONDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetProgramData',
    full_name='Nrmk.IndyFramework.RTDataExchange.GetProgramData',
    index=6,
    containing_service=None,
    input_type=common__msgs__pb2._EMPTY,
    output_type=rtde__msgs__pb2._PROGRAMDATA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TestFunction',
    full_name='Nrmk.IndyFramework.RTDataExchange.TestFunction',
    index=7,
    containing_service=None,
    input_type=rtde__msgs__pb2._TESTREQUEST,
    output_type=rtde__msgs__pb2._TESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RTDATAEXCHANGE)

DESCRIPTOR.services_by_name['RTDataExchange'] = _RTDATAEXCHANGE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import common_msgs_pb2 as common__msgs__pb2
import moby_msgs_pb2 as moby__msgs__pb2


class MobyStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMobyState = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetMobyState',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.MobyState.FromString,
                )
        self.GetMobyErrorState = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetMobyErrorState',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.MobyErrorState.FromString,
                )
        self.Recover = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/Recover',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetMobyPose = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetMobyPose',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.MobyPose.FromString,
                )
        self.GetMobyVel = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetMobyVel',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.MobyVel.FromString,
                )
        self.ResetMobyPose = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/ResetMobyPose',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetRotationAngleDeg = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetRotationAngleDeg',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.SwerveDoubles.FromString,
                )
        self.GetDriveSpeed = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetDriveSpeed',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.SwerveDoubles.FromString,
                )
        self.GetTargetVel = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetTargetVel',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.TargetVel.FromString,
                )
        self.GetRotationZeroCount = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetRotationZeroCount',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.ZeroCount.FromString,
                )
        self.GetGyroData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetGyroData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.DoubleVals.FromString,
                )
        self.ResetGyroSensor = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/ResetGyroSensor',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.UseGyroForOdom = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/UseGyroForOdom',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetGyroFullData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetGyroFullData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.IMUData.FromString,
                )
        self.GetIRSensorData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetIRSensorData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.IRData.FromString,
                )
        self.GetUSSensorData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetUSSensorData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.USData.FromString,
                )
        self.GetBMSData = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetBMSData',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.BMSData.FromString,
                )
        self.SetStepControl = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetStepControl',
                request_serializer=moby__msgs__pb2.TargetVel.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.StopMotion = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/StopMotion',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetRotationAngleDeg = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetRotationAngleDeg',
                request_serializer=moby__msgs__pb2.SwerveDoubles.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.DriveWheel = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/DriveWheel',
                request_serializer=moby__msgs__pb2.SwerveDoubles.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetZeroPosAsCurrentPos = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetZeroPosAsCurrentPos',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetRotationVelAcc = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetRotationVelAcc',
                request_serializer=moby__msgs__pb2.DoubleVals.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetRotationInterpolator = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetRotationInterpolator',
                request_serializer=moby__msgs__pb2.IntVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetDriveAccDec = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetDriveAccDec',
                request_serializer=moby__msgs__pb2.DoubleVals.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetDriveInterpolatorOnOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetDriveInterpolatorOnOff',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetRotationControllerType = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetRotationControllerType',
                request_serializer=moby__msgs__pb2.IntVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetForceKinematics = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetForceKinematics',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetForceKinematics = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetForceKinematics',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=moby__msgs__pb2.BoolVal.FromString,
                )
        self.PauseBumper = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/PauseBumper',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.TurnLightOnOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/TurnLightOnOff',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.TurnBuzzOnOff = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/TurnBuzzOnOff',
                request_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.SetControlParam = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/SetControlParam',
                request_serializer=moby__msgs__pb2.RotationGain.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.GetControlParam = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/GetControlParam',
                request_serializer=moby__msgs__pb2.IntVal.SerializeToString,
                response_deserializer=moby__msgs__pb2.RotationGain.FromString,
                )
        self.StartRTLogging = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/StartRTLogging',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )
        self.EndRTLogging = channel.unary_unary(
                '/Nrmk.IndyFramework.Moby/EndRTLogging',
                request_serializer=common__msgs__pb2.Empty.SerializeToString,
                response_deserializer=common__msgs__pb2.Empty.FromString,
                )


class MobyServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetMobyState(self, request, context):
        """Get Moby state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMobyErrorState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Recover(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMobyPose(self, request, context):
        """Get Moby's odometry and physical data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMobyVel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetMobyPose(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRotationAngleDeg(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDriveSpeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTargetVel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRotationZeroCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGyroData(self, request, context):
        """Gyro value related
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetGyroSensor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UseGyroForOdom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGyroFullData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIRSensorData(self, request, context):
        """IR sensor
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUSSensorData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBMSData(self, request, context):
        """BMS data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetStepControl(self, request, context):
        """Moby motion command
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopMotion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRotationAngleDeg(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DriveWheel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetZeroPosAsCurrentPos(self, request, context):
        """Set Moby parameters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRotationVelAcc(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRotationInterpolator(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDriveAccDec(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetDriveInterpolatorOnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRotationControllerType(self, request, context):
        """rpc SetRotationInterpolatorParam(DoubleVals) returns (Empty) {}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetForceKinematics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetForceKinematics(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseBumper(self, request, context):
        """Moby-Agri related commands
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TurnLightOnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TurnBuzzOnOff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetControlParam(self, request, context):
        """Gain setting
        rpc SetRotationTorqueMode(BoolVal) returns (Empty) {}
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetControlParam(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartRTLogging(self, request, context):
        """Data logging
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EndRTLogging(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MobyServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMobyState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobyState,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.MobyState.SerializeToString,
            ),
            'GetMobyErrorState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobyErrorState,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.MobyErrorState.SerializeToString,
            ),
            'Recover': grpc.unary_unary_rpc_method_handler(
                    servicer.Recover,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetMobyPose': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobyPose,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.MobyPose.SerializeToString,
            ),
            'GetMobyVel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobyVel,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.MobyVel.SerializeToString,
            ),
            'ResetMobyPose': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetMobyPose,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetRotationAngleDeg': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRotationAngleDeg,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.SwerveDoubles.SerializeToString,
            ),
            'GetDriveSpeed': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDriveSpeed,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.SwerveDoubles.SerializeToString,
            ),
            'GetTargetVel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTargetVel,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.TargetVel.SerializeToString,
            ),
            'GetRotationZeroCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRotationZeroCount,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.ZeroCount.SerializeToString,
            ),
            'GetGyroData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGyroData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.DoubleVals.SerializeToString,
            ),
            'ResetGyroSensor': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetGyroSensor,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'UseGyroForOdom': grpc.unary_unary_rpc_method_handler(
                    servicer.UseGyroForOdom,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetGyroFullData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGyroFullData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.IMUData.SerializeToString,
            ),
            'GetIRSensorData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIRSensorData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.IRData.SerializeToString,
            ),
            'GetUSSensorData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUSSensorData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.USData.SerializeToString,
            ),
            'GetBMSData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBMSData,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.BMSData.SerializeToString,
            ),
            'SetStepControl': grpc.unary_unary_rpc_method_handler(
                    servicer.SetStepControl,
                    request_deserializer=moby__msgs__pb2.TargetVel.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'StopMotion': grpc.unary_unary_rpc_method_handler(
                    servicer.StopMotion,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetRotationAngleDeg': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRotationAngleDeg,
                    request_deserializer=moby__msgs__pb2.SwerveDoubles.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'DriveWheel': grpc.unary_unary_rpc_method_handler(
                    servicer.DriveWheel,
                    request_deserializer=moby__msgs__pb2.SwerveDoubles.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetZeroPosAsCurrentPos': grpc.unary_unary_rpc_method_handler(
                    servicer.SetZeroPosAsCurrentPos,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetRotationVelAcc': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRotationVelAcc,
                    request_deserializer=moby__msgs__pb2.DoubleVals.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetRotationInterpolator': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRotationInterpolator,
                    request_deserializer=moby__msgs__pb2.IntVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetDriveAccDec': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDriveAccDec,
                    request_deserializer=moby__msgs__pb2.DoubleVals.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetDriveInterpolatorOnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.SetDriveInterpolatorOnOff,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetRotationControllerType': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRotationControllerType,
                    request_deserializer=moby__msgs__pb2.IntVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetForceKinematics': grpc.unary_unary_rpc_method_handler(
                    servicer.SetForceKinematics,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetForceKinematics': grpc.unary_unary_rpc_method_handler(
                    servicer.GetForceKinematics,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=moby__msgs__pb2.BoolVal.SerializeToString,
            ),
            'PauseBumper': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseBumper,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'TurnLightOnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.TurnLightOnOff,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'TurnBuzzOnOff': grpc.unary_unary_rpc_method_handler(
                    servicer.TurnBuzzOnOff,
                    request_deserializer=moby__msgs__pb2.BoolVal.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'SetControlParam': grpc.unary_unary_rpc_method_handler(
                    servicer.SetControlParam,
                    request_deserializer=moby__msgs__pb2.RotationGain.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'GetControlParam': grpc.unary_unary_rpc_method_handler(
                    servicer.GetControlParam,
                    request_deserializer=moby__msgs__pb2.IntVal.FromString,
                    response_serializer=moby__msgs__pb2.RotationGain.SerializeToString,
            ),
            'StartRTLogging': grpc.unary_unary_rpc_method_handler(
                    servicer.StartRTLogging,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
            'EndRTLogging': grpc.unary_unary_rpc_method_handler(
                    servicer.EndRTLogging,
                    request_deserializer=common__msgs__pb2.Empty.FromString,
                    response_serializer=common__msgs__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Nrmk.IndyFramework.Moby', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Moby(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetMobyState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetMobyState',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.MobyState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMobyErrorState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetMobyErrorState',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.MobyErrorState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Recover(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/Recover',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMobyPose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetMobyPose',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.MobyPose.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMobyVel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetMobyVel',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.MobyVel.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetMobyPose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/ResetMobyPose',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRotationAngleDeg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetRotationAngleDeg',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.SwerveDoubles.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDriveSpeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetDriveSpeed',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.SwerveDoubles.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTargetVel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetTargetVel',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.TargetVel.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRotationZeroCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetRotationZeroCount',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.ZeroCount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGyroData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetGyroData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.DoubleVals.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetGyroSensor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/ResetGyroSensor',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UseGyroForOdom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/UseGyroForOdom',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGyroFullData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetGyroFullData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.IMUData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIRSensorData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetIRSensorData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.IRData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUSSensorData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetUSSensorData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.USData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBMSData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetBMSData',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.BMSData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetStepControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetStepControl',
            moby__msgs__pb2.TargetVel.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopMotion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/StopMotion',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRotationAngleDeg(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetRotationAngleDeg',
            moby__msgs__pb2.SwerveDoubles.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DriveWheel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/DriveWheel',
            moby__msgs__pb2.SwerveDoubles.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetZeroPosAsCurrentPos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetZeroPosAsCurrentPos',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRotationVelAcc(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetRotationVelAcc',
            moby__msgs__pb2.DoubleVals.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRotationInterpolator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetRotationInterpolator',
            moby__msgs__pb2.IntVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDriveAccDec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetDriveAccDec',
            moby__msgs__pb2.DoubleVals.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetDriveInterpolatorOnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetDriveInterpolatorOnOff',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetRotationControllerType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetRotationControllerType',
            moby__msgs__pb2.IntVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetForceKinematics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetForceKinematics',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetForceKinematics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetForceKinematics',
            common__msgs__pb2.Empty.SerializeToString,
            moby__msgs__pb2.BoolVal.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseBumper(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/PauseBumper',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TurnLightOnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/TurnLightOnOff',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TurnBuzzOnOff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/TurnBuzzOnOff',
            moby__msgs__pb2.BoolVal.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetControlParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/SetControlParam',
            moby__msgs__pb2.RotationGain.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetControlParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/GetControlParam',
            moby__msgs__pb2.IntVal.SerializeToString,
            moby__msgs__pb2.RotationGain.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartRTLogging(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/StartRTLogging',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EndRTLogging(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Nrmk.IndyFramework.Moby/EndRTLogging',
            common__msgs__pb2.Empty.SerializeToString,
            common__msgs__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: moby_msgs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='moby_msgs.proto',
  package='Nrmk.IndyFramework',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fmoby_msgs.proto\x12\x12Nrmk.IndyFramework\" \n\nDriveIndex\x12\x12\n\nmoby_index\x18\x01 \x01(\r\"}\n\rMotorDriverTx\x12\x12\n\nstatusWord\x18\x01 \x01(\r\x12\x12\n\nmodeOpDisp\x18\x02 \x01(\x05\x12\x16\n\x0e\x61\x63tualPosition\x18\x03 \x01(\x05\x12\x16\n\x0e\x61\x63tualVelocity\x18\x04 \x01(\x05\x12\x14\n\x0c\x61\x63tualTorque\x18\x05 \x01(\x05\"z\n\rMotorDriverRx\x12\x13\n\x0b\x63ontrolWord\x18\x01 \x01(\r\x12\x0e\n\x06modeOp\x18\x02 \x01(\x05\x12\x16\n\x0etargetPosition\x18\x03 \x01(\x05\x12\x16\n\x0etargetVelocity\x18\x04 \x01(\x05\x12\x14\n\x0ctargetTorque\x18\x05 \x01(\x05\"i\n\tMobyState\x12\x0e\n\x06status\x18\x01 \x01(\r\x12\x10\n\x08is_ready\x18\x02 \x01(\x08\x12\x11\n\tis_enable\x18\x03 \x01(\x08\x12\x11\n\tis_moving\x18\x04 \x01(\x08\x12\x14\n\x0cis_violation\x18\x05 \x01(\x08\"c\n\x0eMobyErrorState\x12\x12\n\nerrorState\x18\x01 \x01(\x04\x12\x13\n\x0b\x65rrorIndex1\x18\x02 \x01(\x05\x12\x13\n\x0b\x65rrorIndex2\x18\x03 \x01(\x05\x12\x13\n\x0b\x65rrorIndex3\x18\x04 \x01(\x05\".\n\x08MobyPose\x12\n\n\x02px\x18\x01 \x01(\x01\x12\n\n\x02py\x18\x02 \x01(\x01\x12\n\n\x02pw\x18\x03 \x01(\x01\"-\n\x07MobyVel\x12\n\n\x02vx\x18\x01 \x01(\x01\x12\n\n\x02vy\x18\x02 \x01(\x01\x12\n\n\x02vw\x18\x03 \x01(\x01\"\xa5\x01\n\x07IMUData\x12\x0e\n\x06\x61ngleX\x18\x01 \x01(\x01\x12\x0e\n\x06\x61ngleY\x18\x02 \x01(\x01\x12\x0e\n\x06\x61ngleZ\x18\x03 \x01(\x01\x12\x11\n\tangleVelX\x18\x04 \x01(\x01\x12\x11\n\tangleVelY\x18\x05 \x01(\x01\x12\x11\n\tangleVelZ\x18\x06 \x01(\x01\x12\x0f\n\x07linAccX\x18\x07 \x01(\x01\x12\x0f\n\x07linAccY\x18\x08 \x01(\x01\x12\x0f\n\x07linAccZ\x18\t \x01(\x01\"?\n\rSwerveDoubles\x12\n\n\x02\x66l\x18\x01 \x01(\x01\x12\n\n\x02\x66r\x18\x02 \x01(\x01\x12\n\n\x02\x62l\x18\x03 \x01(\x01\x12\n\n\x02\x62r\x18\x04 \x01(\x01\"/\n\tTargetVel\x12\n\n\x02vx\x18\x01 \x01(\x01\x12\n\n\x02vy\x18\x02 \x01(\x01\x12\n\n\x02vw\x18\x03 \x01(\x01\";\n\tZeroCount\x12\n\n\x02\x66l\x18\x01 \x01(\x05\x12\n\n\x02\x66r\x18\x02 \x01(\x05\x12\n\n\x02\x62l\x18\x03 \x01(\x05\x12\n\n\x02\x62r\x18\x04 \x01(\x05\"\xae\x01\n\x06IRData\x12\x11\n\tir_front1\x18\x01 \x01(\x05\x12\x11\n\tir_front2\x18\x02 \x01(\x05\x12\x10\n\x08ir_left1\x18\x03 \x01(\x05\x12\x10\n\x08ir_left2\x18\x04 \x01(\x05\x12\x10\n\x08ir_left3\x18\x05 \x01(\x05\x12\x0f\n\x07ir_rear\x18\x06 \x01(\x05\x12\x11\n\tir_right1\x18\x07 \x01(\x05\x12\x11\n\tir_right2\x18\x08 \x01(\x05\x12\x11\n\tir_right3\x18\t \x01(\x05\"\x89\x03\n\x06USData\x12\x16\n\x0eus_front_left1\x18\x01 \x01(\x05\x12\x16\n\x0eus_front_left2\x18\x02 \x01(\x05\x12\x16\n\x0eus_front_left3\x18\x03 \x01(\x05\x12\x17\n\x0fus_front_ground\x18\x04 \x01(\x05\x12\x17\n\x0fus_front_right1\x18\x05 \x01(\x05\x12\x17\n\x0fus_front_right2\x18\x06 \x01(\x05\x12\x17\n\x0fus_front_right3\x18\x07 \x01(\x05\x12\x17\n\x0fus_front_right4\x18\x08 \x01(\x05\x12\x16\n\x0eus_back_right1\x18\t \x01(\x05\x12\x16\n\x0eus_back_right2\x18\n \x01(\x05\x12\x16\n\x0eus_back_right3\x18\x0b \x01(\x05\x12\x16\n\x0eus_back_ground\x18\x0c \x01(\x05\x12\x15\n\rus_back_left1\x18\r \x01(\x05\x12\x15\n\rus_back_left2\x18\x0e \x01(\x05\x12\x15\n\rus_back_left3\x18\x0f \x01(\x05\x12\x15\n\rus_back_left4\x18\x10 \x01(\x05\"\xcc\x03\n\x07\x42MSData\x12\x12\n\nbms_status\x18\x01 \x03(\x05\x12\x11\n\tpack_volt\x18\x02 \x03(\x05\x12\x14\n\x0c\x62\x61ttery_volt\x18\x03 \x03(\x05\x12\x15\n\rpack_current1\x18\x04 \x03(\x05\x12\x15\n\rpack_current2\x18\x05 \x03(\x05\x12\x10\n\x08isCharge\x18\x06 \x01(\x05\x12\x16\n\x0eisCellOverVolt\x18\x07 \x01(\x05\x12\x17\n\x0fisCellUnderVolt\x18\x08 \x01(\x05\x12\x17\n\x0fisOverCurCharge\x18\t \x01(\x05\x12\x18\n\x10isOverCurDischrg\x18\n \x01(\x05\x12\x16\n\x0eisShortCircuit\x18\x0b \x01(\x05\x12\x19\n\x11isOverTemperature\x18\x0c \x01(\x05\x12\x16\n\x0eisPackOverVolt\x18\r \x01(\x05\x12\x0b\n\x03SOC\x18\x0e \x01(\x05\x12\x0b\n\x03SOH\x18\x0f \x01(\x05\x12\x13\n\x0btime_charge\x18\x10 \x01(\x05\x12\x14\n\x0ctime_dcharge\x18\x11 \x01(\x05\x12\x11\n\trem_capAh\x18\x12 \x01(\x05\x12\x11\n\trem_capWh\x18\x13 \x01(\x05\x12\x17\n\x0f\x62ms_temperature\x18\x14 \x03(\x05\x12\x11\n\tcell_volt\x18\x15 \x03(\x05\"!\n\x05GBool\x12\x0b\n\x03idx\x18\x01 \x01(\x05\x12\x0b\n\x03val\x18\x02 \x01(\x08\" \n\x04GInt\x12\x0b\n\x03idx\x18\x01 \x01(\x05\x12\x0b\n\x03val\x18\x02 \x01(\x05\"\"\n\x06GFloat\x12\x0b\n\x03idx\x18\x01 \x01(\x05\x12\x0b\n\x03val\x18\x02 \x01(\x02\"#\n\x07GString\x12\x0b\n\x03idx\x18\x01 \x01(\x05\x12\x0b\n\x03val\x18\x02 \x01(\t\"\x16\n\x07\x42oolVal\x12\x0b\n\x03val\x18\x01 \x01(\x08\"\x15\n\x06IntVal\x12\x0b\n\x03val\x18\x01 \x01(\x05\"\x16\n\x07IntVals\x12\x0b\n\x03val\x18\x01 \x03(\x05\"\x17\n\x08\x46loatVal\x12\x0b\n\x03val\x18\x01 \x01(\x02\"\x18\n\tFloatVals\x12\x0b\n\x03val\x18\x01 \x03(\x02\"\x18\n\tDoubleVal\x12\x0b\n\x03val\x18\x01 \x01(\x01\"\x19\n\nDoubleVals\x12\x0b\n\x03val\x18\x01 \x03(\x01\">\n\x0cRotationGain\x12\x0b\n\x03idx\x18\x01 \x01(\x05\x12\t\n\x01k\x18\x02 \x01(\x01\x12\n\n\x02kv\x18\x03 \x01(\x01\x12\n\n\x02kp\x18\x04 \x01(\x01\"9\n\x0eVelAccBoundary\x12\x0b\n\x03idx\x18\x01 \x01(\x05\x12\x0c\n\x04vmax\x18\x02 \x01(\x02\x12\x0c\n\x04\x61max\x18\x03 \x01(\x02\x62\x06proto3'
)




_DRIVEINDEX = _descriptor.Descriptor(
  name='DriveIndex',
  full_name='Nrmk.IndyFramework.DriveIndex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='moby_index', full_name='Nrmk.IndyFramework.DriveIndex.moby_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=71,
)


_MOTORDRIVERTX = _descriptor.Descriptor(
  name='MotorDriverTx',
  full_name='Nrmk.IndyFramework.MotorDriverTx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statusWord', full_name='Nrmk.IndyFramework.MotorDriverTx.statusWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modeOpDisp', full_name='Nrmk.IndyFramework.MotorDriverTx.modeOpDisp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualPosition', full_name='Nrmk.IndyFramework.MotorDriverTx.actualPosition', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualVelocity', full_name='Nrmk.IndyFramework.MotorDriverTx.actualVelocity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualTorque', full_name='Nrmk.IndyFramework.MotorDriverTx.actualTorque', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=198,
)


_MOTORDRIVERRX = _descriptor.Descriptor(
  name='MotorDriverRx',
  full_name='Nrmk.IndyFramework.MotorDriverRx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controlWord', full_name='Nrmk.IndyFramework.MotorDriverRx.controlWord', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modeOp', full_name='Nrmk.IndyFramework.MotorDriverRx.modeOp', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPosition', full_name='Nrmk.IndyFramework.MotorDriverRx.targetPosition', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetVelocity', full_name='Nrmk.IndyFramework.MotorDriverRx.targetVelocity', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetTorque', full_name='Nrmk.IndyFramework.MotorDriverRx.targetTorque', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=322,
)


_MOBYSTATE = _descriptor.Descriptor(
  name='MobyState',
  full_name='Nrmk.IndyFramework.MobyState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Nrmk.IndyFramework.MobyState.status', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_ready', full_name='Nrmk.IndyFramework.MobyState.is_ready', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enable', full_name='Nrmk.IndyFramework.MobyState.is_enable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_moving', full_name='Nrmk.IndyFramework.MobyState.is_moving', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_violation', full_name='Nrmk.IndyFramework.MobyState.is_violation', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=324,
  serialized_end=429,
)


_MOBYERRORSTATE = _descriptor.Descriptor(
  name='MobyErrorState',
  full_name='Nrmk.IndyFramework.MobyErrorState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='errorState', full_name='Nrmk.IndyFramework.MobyErrorState.errorState', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorIndex1', full_name='Nrmk.IndyFramework.MobyErrorState.errorIndex1', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorIndex2', full_name='Nrmk.IndyFramework.MobyErrorState.errorIndex2', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorIndex3', full_name='Nrmk.IndyFramework.MobyErrorState.errorIndex3', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=530,
)


_MOBYPOSE = _descriptor.Descriptor(
  name='MobyPose',
  full_name='Nrmk.IndyFramework.MobyPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='px', full_name='Nrmk.IndyFramework.MobyPose.px', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='py', full_name='Nrmk.IndyFramework.MobyPose.py', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pw', full_name='Nrmk.IndyFramework.MobyPose.pw', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=578,
)


_MOBYVEL = _descriptor.Descriptor(
  name='MobyVel',
  full_name='Nrmk.IndyFramework.MobyVel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vx', full_name='Nrmk.IndyFramework.MobyVel.vx', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vy', full_name='Nrmk.IndyFramework.MobyVel.vy', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vw', full_name='Nrmk.IndyFramework.MobyVel.vw', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=625,
)


_IMUDATA = _descriptor.Descriptor(
  name='IMUData',
  full_name='Nrmk.IndyFramework.IMUData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='angleX', full_name='Nrmk.IndyFramework.IMUData.angleX', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angleY', full_name='Nrmk.IndyFramework.IMUData.angleY', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angleZ', full_name='Nrmk.IndyFramework.IMUData.angleZ', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angleVelX', full_name='Nrmk.IndyFramework.IMUData.angleVelX', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angleVelY', full_name='Nrmk.IndyFramework.IMUData.angleVelY', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angleVelZ', full_name='Nrmk.IndyFramework.IMUData.angleVelZ', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linAccX', full_name='Nrmk.IndyFramework.IMUData.linAccX', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linAccY', full_name='Nrmk.IndyFramework.IMUData.linAccY', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linAccZ', full_name='Nrmk.IndyFramework.IMUData.linAccZ', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=793,
)


_SWERVEDOUBLES = _descriptor.Descriptor(
  name='SwerveDoubles',
  full_name='Nrmk.IndyFramework.SwerveDoubles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fl', full_name='Nrmk.IndyFramework.SwerveDoubles.fl', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fr', full_name='Nrmk.IndyFramework.SwerveDoubles.fr', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bl', full_name='Nrmk.IndyFramework.SwerveDoubles.bl', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='br', full_name='Nrmk.IndyFramework.SwerveDoubles.br', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=795,
  serialized_end=858,
)


_TARGETVEL = _descriptor.Descriptor(
  name='TargetVel',
  full_name='Nrmk.IndyFramework.TargetVel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vx', full_name='Nrmk.IndyFramework.TargetVel.vx', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vy', full_name='Nrmk.IndyFramework.TargetVel.vy', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vw', full_name='Nrmk.IndyFramework.TargetVel.vw', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=860,
  serialized_end=907,
)


_ZEROCOUNT = _descriptor.Descriptor(
  name='ZeroCount',
  full_name='Nrmk.IndyFramework.ZeroCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fl', full_name='Nrmk.IndyFramework.ZeroCount.fl', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fr', full_name='Nrmk.IndyFramework.ZeroCount.fr', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bl', full_name='Nrmk.IndyFramework.ZeroCount.bl', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='br', full_name='Nrmk.IndyFramework.ZeroCount.br', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=909,
  serialized_end=968,
)


_IRDATA = _descriptor.Descriptor(
  name='IRData',
  full_name='Nrmk.IndyFramework.IRData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ir_front1', full_name='Nrmk.IndyFramework.IRData.ir_front1', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ir_front2', full_name='Nrmk.IndyFramework.IRData.ir_front2', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ir_left1', full_name='Nrmk.IndyFramework.IRData.ir_left1', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ir_left2', full_name='Nrmk.IndyFramework.IRData.ir_left2', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ir_left3', full_name='Nrmk.IndyFramework.IRData.ir_left3', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ir_rear', full_name='Nrmk.IndyFramework.IRData.ir_rear', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ir_right1', full_name='Nrmk.IndyFramework.IRData.ir_right1', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ir_right2', full_name='Nrmk.IndyFramework.IRData.ir_right2', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ir_right3', full_name='Nrmk.IndyFramework.IRData.ir_right3', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1145,
)


_USDATA = _descriptor.Descriptor(
  name='USData',
  full_name='Nrmk.IndyFramework.USData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='us_front_left1', full_name='Nrmk.IndyFramework.USData.us_front_left1', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_front_left2', full_name='Nrmk.IndyFramework.USData.us_front_left2', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_front_left3', full_name='Nrmk.IndyFramework.USData.us_front_left3', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_front_ground', full_name='Nrmk.IndyFramework.USData.us_front_ground', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_front_right1', full_name='Nrmk.IndyFramework.USData.us_front_right1', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_front_right2', full_name='Nrmk.IndyFramework.USData.us_front_right2', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_front_right3', full_name='Nrmk.IndyFramework.USData.us_front_right3', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_front_right4', full_name='Nrmk.IndyFramework.USData.us_front_right4', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_back_right1', full_name='Nrmk.IndyFramework.USData.us_back_right1', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_back_right2', full_name='Nrmk.IndyFramework.USData.us_back_right2', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_back_right3', full_name='Nrmk.IndyFramework.USData.us_back_right3', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_back_ground', full_name='Nrmk.IndyFramework.USData.us_back_ground', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_back_left1', full_name='Nrmk.IndyFramework.USData.us_back_left1', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_back_left2', full_name='Nrmk.IndyFramework.USData.us_back_left2', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_back_left3', full_name='Nrmk.IndyFramework.USData.us_back_left3', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='us_back_left4', full_name='Nrmk.IndyFramework.USData.us_back_left4', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1148,
  serialized_end=1541,
)


_BMSDATA = _descriptor.Descriptor(
  name='BMSData',
  full_name='Nrmk.IndyFramework.BMSData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bms_status', full_name='Nrmk.IndyFramework.BMSData.bms_status', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pack_volt', full_name='Nrmk.IndyFramework.BMSData.pack_volt', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_volt', full_name='Nrmk.IndyFramework.BMSData.battery_volt', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pack_current1', full_name='Nrmk.IndyFramework.BMSData.pack_current1', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pack_current2', full_name='Nrmk.IndyFramework.BMSData.pack_current2', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isCharge', full_name='Nrmk.IndyFramework.BMSData.isCharge', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isCellOverVolt', full_name='Nrmk.IndyFramework.BMSData.isCellOverVolt', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isCellUnderVolt', full_name='Nrmk.IndyFramework.BMSData.isCellUnderVolt', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isOverCurCharge', full_name='Nrmk.IndyFramework.BMSData.isOverCurCharge', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isOverCurDischrg', full_name='Nrmk.IndyFramework.BMSData.isOverCurDischrg', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isShortCircuit', full_name='Nrmk.IndyFramework.BMSData.isShortCircuit', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isOverTemperature', full_name='Nrmk.IndyFramework.BMSData.isOverTemperature', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isPackOverVolt', full_name='Nrmk.IndyFramework.BMSData.isPackOverVolt', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SOC', full_name='Nrmk.IndyFramework.BMSData.SOC', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SOH', full_name='Nrmk.IndyFramework.BMSData.SOH', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_charge', full_name='Nrmk.IndyFramework.BMSData.time_charge', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_dcharge', full_name='Nrmk.IndyFramework.BMSData.time_dcharge', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rem_capAh', full_name='Nrmk.IndyFramework.BMSData.rem_capAh', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rem_capWh', full_name='Nrmk.IndyFramework.BMSData.rem_capWh', index=18,
      number=19, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bms_temperature', full_name='Nrmk.IndyFramework.BMSData.bms_temperature', index=19,
      number=20, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_volt', full_name='Nrmk.IndyFramework.BMSData.cell_volt', index=20,
      number=21, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1544,
  serialized_end=2004,
)


_GBOOL = _descriptor.Descriptor(
  name='GBool',
  full_name='Nrmk.IndyFramework.GBool',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idx', full_name='Nrmk.IndyFramework.GBool.idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.GBool.val', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2006,
  serialized_end=2039,
)


_GINT = _descriptor.Descriptor(
  name='GInt',
  full_name='Nrmk.IndyFramework.GInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idx', full_name='Nrmk.IndyFramework.GInt.idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.GInt.val', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2041,
  serialized_end=2073,
)


_GFLOAT = _descriptor.Descriptor(
  name='GFloat',
  full_name='Nrmk.IndyFramework.GFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idx', full_name='Nrmk.IndyFramework.GFloat.idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.GFloat.val', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2075,
  serialized_end=2109,
)


_GSTRING = _descriptor.Descriptor(
  name='GString',
  full_name='Nrmk.IndyFramework.GString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idx', full_name='Nrmk.IndyFramework.GString.idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.GString.val', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2111,
  serialized_end=2146,
)


_BOOLVAL = _descriptor.Descriptor(
  name='BoolVal',
  full_name='Nrmk.IndyFramework.BoolVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.BoolVal.val', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2148,
  serialized_end=2170,
)


_INTVAL = _descriptor.Descriptor(
  name='IntVal',
  full_name='Nrmk.IndyFramework.IntVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.IntVal.val', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2172,
  serialized_end=2193,
)


_INTVALS = _descriptor.Descriptor(
  name='IntVals',
  full_name='Nrmk.IndyFramework.IntVals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.IntVals.val', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2195,
  serialized_end=2217,
)


_FLOATVAL = _descriptor.Descriptor(
  name='FloatVal',
  full_name='Nrmk.IndyFramework.FloatVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.FloatVal.val', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2219,
  serialized_end=2242,
)


_FLOATVALS = _descriptor.Descriptor(
  name='FloatVals',
  full_name='Nrmk.IndyFramework.FloatVals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.FloatVals.val', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2244,
  serialized_end=2268,
)


_DOUBLEVAL = _descriptor.Descriptor(
  name='DoubleVal',
  full_name='Nrmk.IndyFramework.DoubleVal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.DoubleVal.val', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2270,
  serialized_end=2294,
)


_DOUBLEVALS = _descriptor.Descriptor(
  name='DoubleVals',
  full_name='Nrmk.IndyFramework.DoubleVals',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='Nrmk.IndyFramework.DoubleVals.val', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2296,
  serialized_end=2321,
)


_ROTATIONGAIN = _descriptor.Descriptor(
  name='RotationGain',
  full_name='Nrmk.IndyFramework.RotationGain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idx', full_name='Nrmk.IndyFramework.RotationGain.idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k', full_name='Nrmk.IndyFramework.RotationGain.k', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kv', full_name='Nrmk.IndyFramework.RotationGain.kv', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kp', full_name='Nrmk.IndyFramework.RotationGain.kp', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2323,
  serialized_end=2385,
)


_VELACCBOUNDARY = _descriptor.Descriptor(
  name='VelAccBoundary',
  full_name='Nrmk.IndyFramework.VelAccBoundary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idx', full_name='Nrmk.IndyFramework.VelAccBoundary.idx', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vmax', full_name='Nrmk.IndyFramework.VelAccBoundary.vmax', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amax', full_name='Nrmk.IndyFramework.VelAccBoundary.amax', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2387,
  serialized_end=2444,
)

DESCRIPTOR.message_types_by_name['DriveIndex'] = _DRIVEINDEX
DESCRIPTOR.message_types_by_name['MotorDriverTx'] = _MOTORDRIVERTX
DESCRIPTOR.message_types_by_name['MotorDriverRx'] = _MOTORDRIVERRX
DESCRIPTOR.message_types_by_name['MobyState'] = _MOBYSTATE
DESCRIPTOR.message_types_by_name['MobyErrorState'] = _MOBYERRORSTATE
DESCRIPTOR.message_types_by_name['MobyPose'] = _MOBYPOSE
DESCRIPTOR.message_types_by_name['MobyVel'] = _MOBYVEL
DESCRIPTOR.message_types_by_name['IMUData'] = _IMUDATA
DESCRIPTOR.message_types_by_name['SwerveDoubles'] = _SWERVEDOUBLES
DESCRIPTOR.message_types_by_name['TargetVel'] = _TARGETVEL
DESCRIPTOR.message_types_by_name['ZeroCount'] = _ZEROCOUNT
DESCRIPTOR.message_types_by_name['IRData'] = _IRDATA
DESCRIPTOR.message_types_by_name['USData'] = _USDATA
DESCRIPTOR.message_types_by_name['BMSData'] = _BMSDATA
DESCRIPTOR.message_types_by_name['GBool'] = _GBOOL
DESCRIPTOR.message_types_by_name['GInt'] = _GINT
DESCRIPTOR.message_types_by_name['GFloat'] = _GFLOAT
DESCRIPTOR.message_types_by_name['GString'] = _GSTRING
DESCRIPTOR.message_types_by_name['BoolVal'] = _BOOLVAL
DESCRIPTOR.message_types_by_name['IntVal'] = _INTVAL
DESCRIPTOR.message_types_by_name['IntVals'] = _INTVALS
DESCRIPTOR.message_types_by_name['FloatVal'] = _FLOATVAL
DESCRIPTOR.message_types_by_name['FloatVals'] = _FLOATVALS
DESCRIPTOR.message_types_by_name['DoubleVal'] = _DOUBLEVAL
DESCRIPTOR.message_types_by_name['DoubleVals'] = _DOUBLEVALS
DESCRIPTOR.message_types_by_name['RotationGain'] = _ROTATIONGAIN
DESCRIPTOR.message_types_by_name['VelAccBoundary'] = _VELACCBOUNDARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DriveIndex = _reflection.GeneratedProtocolMessageType('DriveIndex', (_message.Message,), {
  'DESCRIPTOR' : _DRIVEINDEX,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DriveIndex)
  })
_sym_db.RegisterMessage(DriveIndex)

MotorDriverTx = _reflection.GeneratedProtocolMessageType('MotorDriverTx', (_message.Message,), {
  'DESCRIPTOR' : _MOTORDRIVERTX,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MotorDriverTx)
  })
_sym_db.RegisterMessage(MotorDriverTx)

MotorDriverRx = _reflection.GeneratedProtocolMessageType('MotorDriverRx', (_message.Message,), {
  'DESCRIPTOR' : _MOTORDRIVERRX,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MotorDriverRx)
  })
_sym_db.RegisterMessage(MotorDriverRx)

MobyState = _reflection.GeneratedProtocolMessageType('MobyState', (_message.Message,), {
  'DESCRIPTOR' : _MOBYSTATE,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MobyState)
  })
_sym_db.RegisterMessage(MobyState)

MobyErrorState = _reflection.GeneratedProtocolMessageType('MobyErrorState', (_message.Message,), {
  'DESCRIPTOR' : _MOBYERRORSTATE,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MobyErrorState)
  })
_sym_db.RegisterMessage(MobyErrorState)

MobyPose = _reflection.GeneratedProtocolMessageType('MobyPose', (_message.Message,), {
  'DESCRIPTOR' : _MOBYPOSE,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MobyPose)
  })
_sym_db.RegisterMessage(MobyPose)

MobyVel = _reflection.GeneratedProtocolMessageType('MobyVel', (_message.Message,), {
  'DESCRIPTOR' : _MOBYVEL,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.MobyVel)
  })
_sym_db.RegisterMessage(MobyVel)

IMUData = _reflection.GeneratedProtocolMessageType('IMUData', (_message.Message,), {
  'DESCRIPTOR' : _IMUDATA,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IMUData)
  })
_sym_db.RegisterMessage(IMUData)

SwerveDoubles = _reflection.GeneratedProtocolMessageType('SwerveDoubles', (_message.Message,), {
  'DESCRIPTOR' : _SWERVEDOUBLES,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.SwerveDoubles)
  })
_sym_db.RegisterMessage(SwerveDoubles)

TargetVel = _reflection.GeneratedProtocolMessageType('TargetVel', (_message.Message,), {
  'DESCRIPTOR' : _TARGETVEL,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.TargetVel)
  })
_sym_db.RegisterMessage(TargetVel)

ZeroCount = _reflection.GeneratedProtocolMessageType('ZeroCount', (_message.Message,), {
  'DESCRIPTOR' : _ZEROCOUNT,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.ZeroCount)
  })
_sym_db.RegisterMessage(ZeroCount)

IRData = _reflection.GeneratedProtocolMessageType('IRData', (_message.Message,), {
  'DESCRIPTOR' : _IRDATA,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IRData)
  })
_sym_db.RegisterMessage(IRData)

USData = _reflection.GeneratedProtocolMessageType('USData', (_message.Message,), {
  'DESCRIPTOR' : _USDATA,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.USData)
  })
_sym_db.RegisterMessage(USData)

BMSData = _reflection.GeneratedProtocolMessageType('BMSData', (_message.Message,), {
  'DESCRIPTOR' : _BMSDATA,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.BMSData)
  })
_sym_db.RegisterMessage(BMSData)

GBool = _reflection.GeneratedProtocolMessageType('GBool', (_message.Message,), {
  'DESCRIPTOR' : _GBOOL,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.GBool)
  })
_sym_db.RegisterMessage(GBool)

GInt = _reflection.GeneratedProtocolMessageType('GInt', (_message.Message,), {
  'DESCRIPTOR' : _GINT,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.GInt)
  })
_sym_db.RegisterMessage(GInt)

GFloat = _reflection.GeneratedProtocolMessageType('GFloat', (_message.Message,), {
  'DESCRIPTOR' : _GFLOAT,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.GFloat)
  })
_sym_db.RegisterMessage(GFloat)

GString = _reflection.GeneratedProtocolMessageType('GString', (_message.Message,), {
  'DESCRIPTOR' : _GSTRING,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.GString)
  })
_sym_db.RegisterMessage(GString)

BoolVal = _reflection.GeneratedProtocolMessageType('BoolVal', (_message.Message,), {
  'DESCRIPTOR' : _BOOLVAL,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.BoolVal)
  })
_sym_db.RegisterMessage(BoolVal)

IntVal = _reflection.GeneratedProtocolMessageType('IntVal', (_message.Message,), {
  'DESCRIPTOR' : _INTVAL,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IntVal)
  })
_sym_db.RegisterMessage(IntVal)

IntVals = _reflection.GeneratedProtocolMessageType('IntVals', (_message.Message,), {
  'DESCRIPTOR' : _INTVALS,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.IntVals)
  })
_sym_db.RegisterMessage(IntVals)

FloatVal = _reflection.GeneratedProtocolMessageType('FloatVal', (_message.Message,), {
  'DESCRIPTOR' : _FLOATVAL,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FloatVal)
  })
_sym_db.RegisterMessage(FloatVal)

FloatVals = _reflection.GeneratedProtocolMessageType('FloatVals', (_message.Message,), {
  'DESCRIPTOR' : _FLOATVALS,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.FloatVals)
  })
_sym_db.RegisterMessage(FloatVals)

DoubleVal = _reflection.GeneratedProtocolMessageType('DoubleVal', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEVAL,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DoubleVal)
  })
_sym_db.RegisterMessage(DoubleVal)

DoubleVals = _reflection.GeneratedProtocolMessageType('DoubleVals', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLEVALS,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.DoubleVals)
  })
_sym_db.RegisterMessage(DoubleVals)

RotationGain = _reflection.GeneratedProtocolMessageType('RotationGain', (_message.Message,), {
  'DESCRIPTOR' : _ROTATIONGAIN,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.RotationGain)
  })
_sym_db.RegisterMessage(RotationGain)

VelAccBoundary = _reflection.GeneratedProtocolMessageType('VelAccBoundary', (_message.Message,), {
  'DESCRIPTOR' : _VELACCBOUNDARY,
  '__module__' : 'moby_msgs_pb2'
  # @@protoc_insertion_point(class_scope:Nrmk.IndyFramework.VelAccBoundary)
  })
_sym_db.RegisterMessage(VelAccBoundary)


# @@protoc_insertion_point(module_scope)
